<?php

namespace FiloBlu\Adminordergrid\Setup;

use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\DB\Ddl\Table;

class InstallSchema implements InstallSchemaInterface
{
    /**
     * Installs DB schema for a module
     *
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     * @return void
     */
    public function install(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $installer = $setup;
        $installer->startSetup();
        
        /** @var $connection \Magento\Framework\DB\Adapter\Pdo\MySql */
        $connection = $setup->getConnection();
        $gridTableName = $setup->getTable('sales_order_grid');
        $paymentTableName = $setup->getTable('sales_order_payment');

        $cctypeColumns = [
            'type' => Table::TYPE_TEXT,
            'length' => 32,
            'nullable' => true,
            'comment' => 'Payment CC Type',
        ];

        $connection->addColumn(
            $gridTableName,
            'payment_cctype',
            $cctypeColumns
        );
        
        
        //Populate "cc_type" in sales_order_grid with values in sales_order_payments
        $connection->query(
            $connection->updateFromSelect(
                $connection->select()
                    ->join(
                        $paymentTableName,
                        sprintf('%s.entity_id = %s.parent_id', $gridTableName, $paymentTableName),
                        'cc_type AS payment_cctype'
                    ),
                $gridTableName
            )
        );
        
        $installer->endSetup();
        
    }
}